@@ -1,13 +1,23 @@
 #' Pooled Standard Deviation
 #'
-#' The Pooled Standard Deviation is a weighted average of standard deviations for two or more groups, with more "weight" given to larger sample sizes.
+#' The Pooled Standard Deviation is a weighted average of standard deviations
+#' for two or more groups, *assumed to have equal variance*. It represents the
+#' common deviation among the groups, around each of their respective means.
 #'
 #' @inheritParams cohens_d
+#' @inheritParams stats::mad
+#'
+#' @details
+#' The standard version is calculated as:
+#' \deqn{\sqrt{\frac{\sum (x_i - \bar{x})^2}{n_1 + n_2 - 2}}}{sqrt(sum(c(x - mean(x), y - mean(y))^2) / (n1 + n2 - 2))}
+#' The robust version is calculated as:
+#' \deqn{1.4826 \times Median(|\left\{x - Median_x,\,y - Median_y\right\}|)}{mad(c(x - median(x), y - median(y)), constant = 1.4826)}
 #'
 #' @return Numeric, the pooled standard deviation.
 #'
 #' @examples
 #' sd_pooled(mpg ~ am, data = mtcars)
+#' mad_pooled(mtcars$mpg, factor(mtcars$am))
 #' @seealso [cohens_d()]
 #'
 #' @export
@@ -40,8 +50,8 @@ sd_pooled <- function(x, y = NULL, data = NULL, verbose = TRUE) {
 
 #' @rdname sd_pooled
 #' @export
-mad_pooled <- function(x, y = NULL, data = NULL, verbose = TRUE) {
-  .sd_pooled(x, y, data, robust = TRUE, verbose = verbose)
+mad_pooled <- function(x, y = NULL, data = NULL, constant = 1.4826, verbose = TRUE) {
+  .sd_pooled(x, y, data, robust = TRUE, verbose = verbose, constant = constant)
 }
 
 
@@ -51,36 +61,37 @@ mad_pooled <- function(x, y = NULL, data = NULL, verbose = TRUE) {
 
 
 
-#' @importFrom stats mad sd as.formula
-.sd_pooled <- function(x, y = NULL, data = NULL, robust = FALSE, verbose = TRUE) {
+#' @importFrom stats mad sd as.formula ave
+.sd_pooled <- function(x, y = NULL, data = NULL, robust = FALSE, verbose = TRUE, constant = 1) {
 
   # Activate here for evaluation of arguments...
 
   # eval_args <- .evaluate_arguments(x, y, data)
-  # out <- .deal_with_cohens_d_arguments(eval_args$x, eval_args$y, eval_args$data)
+  # out <- .get_data_2_samples(eval_args$x, eval_args$y, eval_args$data)
 
-  out <- .deal_with_cohens_d_arguments(x, y, data, verbose)
+  out <- .get_data_2_samples(x, y, data, verbose)
   x <- na.omit(out$x)
   y <- na.omit(out$y)
 
   if (robust) {
-    sd1 <- stats::mad(x)
-    sd2 <- stats::mad(y)
+    f <- constant
+    center <- stats::median
+    div <- stats::mad
   } else {
-    sd1 <- stats::sd(x)
-    sd2 <- stats::sd(y)
+    n1 <- length(x)
+    n2 <- length(y)
+
+    f <- sqrt(c(n1 + n2 - 1) / c(n1 + n2 - 2))
+    center <- mean
+    div <- stats::sd
   }
 
-  # sqrt((sd1^2 + sd2^2) / 2)
-
-  # Cohen's more complicated formula:
-  n1 <- length(x)
-  n2 <- length(y)
-  sqrt(((n1 - 1) * sd1^2 + (n2 - 1) * sd2^2) / (n1 + n2 - 2))
+  div(c(
+    x - stats::ave(x, FUN = center),
+    y - stats::ave(y, FUN = center)
+  )) * f
 }
 
-
-
 # .evaluate_arguments <- function(x, y, data) {
 #   eval_x <- .evaluate_argument(x)
 #   if (!is.null(eval_x$variable)) x <- eval_x$variable
