@@ -1,9 +1,13 @@
 #' Get Standardization Information
 #'
-#' This function extracts information, such as the deviations (SD or MAD) from parent variables, that are necessary for post-hoc standardization of parameters. This function gives a window on how standardized are obtained, i.e., by what they are devided. The "basic" method of standardization uses
+#' This function extracts information, such as the deviations (SD or MAD) from
+#' parent variables, that are necessary for post-hoc standardization of
+#' parameters. This function gives a window on how standardized are obtained,
+#' i.e., by what they are divided. The "basic" method of standardization uses.
 #'
 #' @inheritParams standardize_parameters
-#' @param include_pseudo (For (G)LMMs) Should Pseudo-standardized information be included?
+#' @param include_pseudo (For (G)LMMs) Should Pseudo-standardized information be
+#'   included?
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @return A data frame with information on each parameter (see
@@ -18,10 +22,14 @@
 #' standardize_info(model)
 #' standardize_info(model, robust = TRUE)
 #' standardize_info(model, two_sd = TRUE)
-#'
 #' @importFrom parameters parameters_type
 #' @export
 standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseudo = FALSE, ...) {
+  UseMethod("standardize_info")
+}
+
+#' @export
+standardize_info.default <- function(model, robust = FALSE, two_sd = FALSE, include_pseudo = FALSE, ...) {
   params <- if (inherits(model, c("glmmTMB", "MixMod"))) {
     insight::find_parameters(model, effects = "fixed", component = "conditional", flatten = TRUE, ...)
   } else {
@@ -79,7 +87,13 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
   # Smart
   out <- merge(
     out,
-    .std_info_predictors_smart(model, data, params, types, robust = robust, two_sd = two_sd),
+    .std_info_predictors_smart(model,
+      data,
+      params,
+      types,
+      robust = robust,
+      two_sd = two_sd
+    ),
     by = "Parameter", all = TRUE
   )
 
@@ -89,7 +103,14 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
     length(insight::find_random(model)$random) == 1) {
     out <- merge(
       out,
-      .std_info_pseudo(model, params, model_matrix, types = types$Type, robust = robust, two_sd = two_sd)
+      .std_info_pseudo(
+        model,
+        params,
+        model_matrix,
+        types = types$Type,
+        robust = robust,
+        two_sd = two_sd
+      )
     )
   }
 
@@ -120,7 +141,13 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
 
 
 #' @keywords internal
-.std_info_predictors_smart <- function(model, data, params, types, robust = FALSE, two_sd = FALSE, ...) {
+.std_info_predictors_smart <- function(model,
+                                       data,
+                                       params,
+                                       types,
+                                       robust = FALSE,
+                                       two_sd = FALSE,
+                                       ...) {
   w <- insight::get_weights(model, na_rm = TRUE)
 
   # Get deviations for all parameters
@@ -150,13 +177,22 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
 
 
 #' @keywords internal
-.std_info_predictor_smart <- function(data, variable, type, robust = FALSE, two_sd = FALSE, weights = NULL, ...) {
+.std_info_predictor_smart <- function(data,
+                                      variable,
+                                      type,
+                                      robust = FALSE,
+                                      two_sd = FALSE,
+                                      weights = NULL,
+                                      ...) {
   if (type == "intercept") {
     info <- list(sd = 0, mean = 0)
   } else if (type == "numeric") {
     info <- .compute_std_info(
-      data = data, variable = variable,
-      robust = robust, two_sd = two_sd, weights = weights
+      data = data,
+      variable = variable,
+      robust = robust,
+      two_sd = two_sd,
+      weights = weights
     )
   } else if (type == "factor") {
     info <- list(sd = 1, mean = 0)
@@ -174,8 +210,11 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
   } else if (type %in% c("interaction", "nested")) {
     if (is.numeric(data[, variable])) {
       info <- .compute_std_info(
-        data = data, variable = variable,
-        robust = robust, two_sd = two_sd, weights = weights
+        data = data,
+        variable = variable,
+        robust = robust,
+        two_sd = two_sd,
+        weights = weights
       )
     } else if (is.factor(data[, variable])) {
       info <- list(sd = 1, mean = 0)
@@ -194,7 +233,12 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
 
 
 #' @keywords internal
-.std_info_predictors_basic <- function(model, model_matrix, types, robust = FALSE, two_sd = FALSE, ...) {
+.std_info_predictors_basic <- function(model,
+                                       model_matrix,
+                                       types,
+                                       robust = FALSE,
+                                       two_sd = FALSE,
+                                       ...) {
   w <- insight::get_weights(model, na_rm = TRUE)
 
   # Get deviations for all parameters
@@ -238,11 +282,13 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
     means <- deviations <- rep(NA_real_, length = length(names(model_matrix)))
     for (i in seq_along(names(model_matrix))) {
       var <- names(model_matrix)[i]
-      if (types$Link[types$Parameter == var] == "Difference") {
+      if (any(types$Parameter == var) &&
+          types$Link[types$Parameter == var] == "Difference") {
         parent_var <- types$Variable[types$Parameter == var]
         intercept <- unique(data[[parent_var]])[1]
         response_at_intercept <- response[data[[parent_var]] == intercept]
         weights_at_intercept <- if (length(w)) w[data[[parent_var]] == intercept] else NULL
+
         std_info <- .compute_std_info(
           response = response_at_intercept,
           robust = robust, weights = weights_at_intercept
@@ -305,20 +351,25 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
 
 # Pseudo (GLMM) -----------------------------------------------------------
 
-
-#' @importFrom insight clean_names get_random model_info find_formula get_variance get_data
-#' @importFrom parameters check_heterogeneity demean
+#' @importFrom insight clean_names get_random model_info find_formula get_variance get_data check_if_installed
+#' @importFrom performance check_heterogeneity_bias
+#' @importFrom datawizard demean
 #' @importFrom stats as.formula sd
-.std_info_pseudo <- function(model, params, model_matrix, types, robust = FALSE, two_sd = FALSE) {
+.std_info_pseudo <- function(model,
+                             params,
+                             model_matrix,
+                             types,
+                             robust = FALSE,
+                             two_sd = FALSE) {
   if (robust) {
     warning("'robust' standardization not available for 'pseudo' method.",
-            call. = FALSE
+      call. = FALSE
     )
   }
 
   f <- if (two_sd) 2 else 1
 
-  within_vars <- unclass(parameters::check_heterogeneity(model))
+  within_vars <- unclass(performance::check_heterogeneity_bias(model))
   id <- insight::get_random(model)[[1]]
   w <- insight::get_weights(model, na_rm = TRUE)
 
@@ -349,7 +400,7 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
     temp_d <- data.frame(model_matrix[, p_check_within, drop = FALSE])
     colnames(temp_d) <- paste0("W", seq_len(ncol(temp_d))) # overwrite because can't deal with ":"
 
-    dm <- parameters::demean(cbind(id, temp_d),
+    dm <- datawizard::demean(cbind(id, temp_d),
       select = colnames(temp_d),
       group = "id"
     )
@@ -367,7 +418,7 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
         "The following within-group terms have between-group variance:\n\t",
         paste0(also_between, collapse = ", "),
         "\nThis can inflate standardized within-group parameters associated with",
-        "\nthese terms. See help(\"demean\", package = \"parameters\") for modeling",
+        "\nthese terms. See help(\"demean\", package = \"datawizard\") for modeling",
         "\nbetween- and within-subject effects.",
         call. = FALSE
       )
@@ -378,9 +429,8 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
   ## Get 2 types of Deviation_Response_Pseudo
   sd_y_within <- sd_y_between <- 1
   if (insight::model_info(model)$is_linear) {
-    if (!requireNamespace("lme4", quietly = TRUE)) {
-      stop("This function requires 'lme4' to work.", call. = FALSE)
-    }
+    insight::check_if_installed("lme4")
+
     rand_name <- insight::find_random(model)$random
 
     # maintain any y-transformations
@@ -451,7 +501,12 @@ standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseu
 
 
 #' @keywords internal
-.compute_std_info <- function(data = NULL, variable = NULL, response = NULL, robust = FALSE, two_sd = FALSE, weights = NULL) {
+.compute_std_info <- function(data = NULL,
+                              variable = NULL,
+                              response = NULL,
+                              robust = FALSE,
+                              two_sd = FALSE,
+                              weights = NULL) {
   f <- if (two_sd) 2 else 1
   if (is.null(response)) {
     response <- as.numeric(data[, variable])
